@@ -1,12 +1,16 @@
 import os
 
 from alagitpull import _version as version
-
+from .writers.external import GitPullHTMLTranslator, ALLOWED_HOSTS
 
 projects = [
     {
         'name': 'unihan-etl',
         'url': 'https://unihan-etl.git-pull.com',
+        'subprojects': [{
+            'name': 'db',
+            'url': 'https://unihan-db.git-pull.com',
+        }]
     }, {
         'name': 'cihai',
         'url': 'https://cihai.git-pull.com',
@@ -47,5 +51,15 @@ def update_context(app, pagename, templatename, context, doctree):
 
 def setup(app):
     app.connect('html-page-context', update_context)
-    return {'version': version.__version__,
-            'parallel_read_safe': True}
+
+    app.set_translator('html', GitPullHTMLTranslator)
+    # for RTD: https://git.io/vAct0
+    app.set_translator('readthedocs', GitPullHTMLTranslator)
+
+    app.add_config_value('alagitpull_internal_hosts', ALLOWED_HOSTS, 'html')
+    app.add_config_value('alagitpull_external_hosts_new_window', False, 'html')
+
+    return {
+        'version': version.__version__,
+        'parallel_read_safe': True,
+    }
